@@ -1,19 +1,19 @@
-from enum import Enum
 from collections import namedtuple
-from typing import Dict, Any, List
+from enum import Enum
+from typing import Any, Dict, List
 
+from samtranslator.model.exceptions import InvalidTemplateException
 from samtranslator.model.intrinsics import (
     is_intrinsic,
     is_intrinsic_if,
     is_intrinsic_no_value,
     validate_intrinsic_if_items,
 )
-from samtranslator.model.exceptions import InvalidTemplateException
 
 PolicyEntry = namedtuple("PolicyEntry", "data type")
 
 
-class ResourcePolicies(object):
+class ResourcePolicies:
     """
     Class encapsulating the policies property of SAM resources. This class strictly encapsulates the data
     and does not take opinions on how to handle them.
@@ -29,7 +29,7 @@ class ResourcePolicies(object):
 
     POLICIES_PROPERTY_NAME = "Policies"
 
-    def __init__(self, resource_properties: Dict[str, Any], policy_template_processor: Any = None):
+    def __init__(self, resource_properties: Dict[str, Any], policy_template_processor: Any = None) -> None:
         """
         Initialize with policies data from resource's properties
 
@@ -51,8 +51,7 @@ class ResourcePolicies(object):
         :yields namedtuple("data", "type"): Yields a named tuple containing the policy data and its type
         """
 
-        for policy_tuple in self.policies:
-            yield policy_tuple
+        yield from self.policies
 
     def __len__(self):  # type: ignore[no-untyped-def]
         return len(self.policies)
@@ -172,7 +171,7 @@ class ResourcePolicies(object):
         try:
             validate_intrinsic_if_items(intrinsic_if_value)
         except ValueError as e:
-            raise InvalidTemplateException(str(e))
+            raise InvalidTemplateException(str(e)) from e
 
         if_data = intrinsic_if_value[1]
         else_data = intrinsic_if_value[2]
